xlwings - Make Excel Fly!
=========================

xlwings is a `BSD-licensed <http://opensource.org/licenses/BSD-3-Clause>`_ Python library that makes it easy to call
Python from Excel and vice versa:

* Interact with Excel from Python using a syntax that is close to VBA yet Pythonic.
* Replace your VBA macros with Python code and still pass around your workbooks as easily as before.

xlwings fully supports NumPy arrays and Pandas DataFrames. It works with Microsoft Excel on Windows and Mac.

.. note:: xlwings is currently in an early stage.
   The API might change in backward incompatible ways.


.. toctree::
    :maxdepth: 2
    :hidden:

    whatsnew
    installation
    quickstart
    connect_to_workbook
    datastructures
    vba
    debugging
    udfs
    command_line
    missing_features
    api





